==> abhi_flutter_alertdialog-0.0.1.tar.gz: lib/src/alertdialog.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

// Alert Dialog

class ShowDialog extends StatelessWidget {

  BuildContext context;
  String title;
  String content;
  String action1;
  String action2;
  Function function1;
  Function function2;

  ShowDialog(
      {this.context,
        this.title,
        this.content,
        this.action1,
        this.action2,
        this.function1,
        this.function2});

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: AlertDialog(
        title: Text(title),
        content: Text(content),
        actions: <Widget>[
          new FlatButton(
              child: new Text(action1),
              onPressed: () {
                function1();
              }),
          new FlatButton(
              child: new Text(action2),
              onPressed: () {
                function2();
              }),
        ],
      ),
    );
  }
}

// Cupertino Dialog

class Cupertino extends StatelessWidget {

  BuildContext context;
  String title;
  String content;
  String action1;
  String action2;
  Function function1;
  Function function2;

  Cupertino(
      {this.context,
        this.title,
        this.content,
        this.action1,
        this.action2,
        this.function1,
        this.function2});

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Padding(
      padding: EdgeInsets.all(8.0),
      child: CupertinoAlertDialog(
        title: new Text(title),
        content: new Text(content),
        actions: <Widget>[
          CupertinoDialogAction(
            isDefaultAction: true,
            child: Text(action1),
            onPressed: (){function1();},
          ),
          CupertinoDialogAction(
            child: Text(action2),
            onPressed: (){function2();},
          )
        ],
      ),
    );
  }
}

==> abhi_flutter_alertdialog-0.0.2.tar.gz: lib/src/alertdialog.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

// Alert Dialog

class AlertDialog1 extends StatelessWidget {

  BuildContext context;
  String title;
  String content;
  String action1;
  String action2;
  Function function1;
  Function function2;

  AlertDialog1(
      {this.context,
        this.title,
        this.content,
        this.action1,
        this.action2,
        this.function1,
        this.function2});

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: AlertDialog(
        title: Text(title),
        content: Text(content),
        actions: <Widget>[
          new FlatButton(
              child: new Text(action1),
              onPressed: () {
                function1();
              }),
          new FlatButton(
              child: new Text(action2),
              onPressed: () {
                function2();
              }),
        ],
      ),
    );
  }
}

// AlertDialog2 Dialog

class AlertDialog2 extends StatelessWidget {

  BuildContext context;
  String title;
  String content;
  String action1;
  String action2;
  Function function1;
  Function function2;

  AlertDialog2(
      {this.context,
        this.title,
        this.content,
        this.action1,
        this.action2,
        this.function1,
        this.function2});

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Padding(
      padding: EdgeInsets.all(8.0),
      child: CupertinoAlertDialog(
        title: new Text(title),
        content: new Text(content),
        actions: <Widget>[
          CupertinoDialogAction(
            isDefaultAction: true,
            child: Text(action1),
            onPressed: (){function1();},
          ),
          CupertinoDialogAction(
            child: Text(action2),
            onPressed: (){function2();},
          )
        ],
      ),
    );
  }
}
